### Photon assisted tunneling:

<img src="https://render.githubusercontent.com/render/math?math=I_{p}(V_0,\alpha) = \sum_{n=-\infty}^{%2B\infty} J_n^2(\alpha) \cdot I_{dc}(V_0 %2B n\hbar \omega / e)">

## Components of <img src="https://render.githubusercontent.com/render/math?math=Y_{mm'} = G_{mm'} %2B\:\: i B_{mm'}">

<img src="https://render.githubusercontent.com/render/math?math=G_{mm'} = \frac{e}{2 \hbar \omega_{m'}} \cdot \:\sum_{n,n'=-\infty}^{\infty} J_n(\alpha) J_{n'}(\alpha) \delta_{m-m', n'-n} \left\{ \left[ I_{dc}(V_0%2Bn' \hbar \omega /e %2B \hbar \omega_{m'}/e) - I_{dc}(V_0 %2B n' \hbar \omega/e) \right] %2B \left[ I_{dc}(V_0 %2B n\hbar \omega/e) - I_{dc}(V_0 %2B n \hbar \omega/e - \hbar \omega_{m'}/e) \right]  \right\}">

<img src="https://render.githubusercontent.com/render/math?math=B_{mm'} = \frac{e}{2 \hbar \omega_{m'}} \cdot \sum_{n,n'=-\infty}^{\infty} J_n(\alpha) J_{n'}(\alpha) \delta_{m-m', n'-n} \left\{ \left[ I_{kk}(V_0%2Bn' \hbar \omega /e %2B \hbar \omega_{m'}/e) - I_{kk}(V_0 %2B n' \hbar \omega/e) \right] - \left[ I_{kk}(V_0 %2B n\hbar \omega/e) - I_{kk}(V_0 %2B n \hbar \omega/e - \hbar \omega_{m'}/e) \right]  \right\}">


<img src="https://render.githubusercontent.com/render/math?math=\omega_m = m \cdot \omega %2B \omega_0">

<img src="https://render.githubusercontent.com/render/math?math=\omega - \text{FFO rate},\:\: \omega_0 - \text{IF rate}, \:\:\omega_m - \text{Signal rate}">


[comment]: <> (__Augmented__ <img src="https://render.githubusercontent.com/render/math?math=Y'_{mm} = \begin{bmatrix} Y_{11} %2B Y_{S} & Y_{10} & Y_{1-1}  \\ Y_{01} & Y_{00} %2B Y_L & Y_{0-1}   \\ Y_{-11} & Y_{-10} & Y_{-1-1}%2BY_I  \\ \end{bmatrix}">)

<img src="https://render.githubusercontent.com/render/math?math=Y_{IF} = 1/Z'_{00} ,\:\: \text{with} \: Y_L = 0 \: \Rightarrow \: Y_{IF} = Y_{00}">


__All there formulas from Tucker & Feldman theory__
